@@ -154,19 +154,24 @@ impl Actor {
         gl::TexParameteri(gl::TEXTURE_2D, gl::TEXTURE_MIN_FILTER, gl::LINEAR as i32);
         gl::TexParameteri(gl::TEXTURE_2D, gl::TEXTURE_MAG_FILTER, gl::LINEAR as i32);
 
-        let img = image::open(&Path::new(&self.image_path)).expect("Failed to load texture");
-        let data = img.raw_pixels();
-
-        gl::TexImage2D(gl::TEXTURE_2D,
+        match image::open(&Path::new(&self.image_path)) {
+          Ok(img) => {
+            let to_rgba = img.to_rgba();
+            let data = to_rgba.into_vec();
+            gl::TexImage2D(gl::TEXTURE_2D,
                       0,
                       gl::RGB as i32,
                       img.width() as i32,
                       img.height() as i32,
                       0,
-                      gl::RGB,
+                      gl::RGBA,
                       gl::UNSIGNED_BYTE,
                       &data[0] as *const u8 as *const c_void);
-        gl::GenerateMipmap(gl::TEXTURE_2D);
+            gl::GenerateMipmap(gl::TEXTURE_2D);
+          }
+          Err(err) => println!("Fail to load a image")
+        }
+
       }
     }
   }
@@ -295,10 +300,6 @@ impl Actor {
       y += main_actor.y as f32;
     }
 
-    for sub_actor in self.sub_actor_list.iter() {
-      sub_actor.render(shader_program, Some(&self));
-    }
-
     let mut transform: Matrix4<f32> = Matrix4::identity();
 
     // Apply orthographic projection matrix: left, right, bottom, top, near, far
@@ -342,9 +343,13 @@ impl Actor {
       gl::BindVertexArray(self.vertex_array_obj);
       gl::DrawElements(gl::TRIANGLES, 6, gl::UNSIGNED_INT, ptr::null());
     }
+
+    for sub_actor in self.sub_actor_list.iter() {
+      sub_actor.render(shader_program, Some(&self));
+    }
   }
 
   pub fn add_sub_actor(&mut self, actor: Actor) {
     self.sub_actor_list.push(actor);
   }
-}
\ No newline at end of file
+}
