@@ -12,7 +12,8 @@ pub struct Stage {
   height: u32,
   viewport_width: u32,
   viewport_height: u32,
-  stage_actor: Actor,
+  visible: bool,
+  pub stage_actor: Actor,
 }
 
 impl Stage {
@@ -22,21 +23,31 @@ impl Stage {
       height: 0,
       viewport_width: vw,
       viewport_height: vh,
+      visible: false,
       stage_actor: Actor::new("stage_actor".to_string(), vw, vh),
     }
   }
 
   pub fn initialize(&mut self) {
+    self.stage_actor.init_gl(self.viewport_width, self.viewport_height);
+  }
 
+  pub fn set_visible(&mut self, visible: bool) {
+    self.visible = visible;
   }
 
   pub fn render(&mut self, shader_program: GLuint) {
+    if !self.visible {
+      return
+    }
     self.stage_actor.animate();
     self.stage_actor.render(shader_program, None);
   }
 
-  pub fn add_actor(&mut self, mut actor: Actor) {
+  pub fn add_actor(&mut self, mut actor: Actor) -> usize {
     actor.init_gl(self.viewport_width, self.viewport_height);
     self.stage_actor.sub_actor_list.push(actor);
+
+    self.stage_actor.sub_actor_list.len() - 1
   }
 }
\ No newline at end of file
